about summary refs log tree commit diff
path: root/pkgs/development/python-modules/phik/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/development/python-modules/phik/default.nix')
-rw-r--r--pkgs/development/python-modules/phik/default.nix83
1 files changed, 29 insertions, 54 deletions
diff --git a/pkgs/development/python-modules/phik/default.nix b/pkgs/development/python-modules/phik/default.nix
index b2dae6f29b1ee..af3c33f908bee 100644
--- a/pkgs/development/python-modules/phik/default.nix
+++ b/pkgs/development/python-modules/phik/default.nix
@@ -1,22 +1,20 @@
-{ lib
-, buildPythonPackage
-, cmake
-, fetchFromGitHub
-, joblib
-, jupyter
-, jupyter-client
-, matplotlib
-, nbconvert
-, ninja
-, numba
-, numpy
-, pandas
-, pybind11
-, pytestCheckHook
-, pythonOlder
-, scikit-build
-, scipy
-, setuptools
+{
+  lib,
+  buildPythonPackage,
+  cmake,
+  fetchFromGitHub,
+  joblib,
+  matplotlib,
+  ninja,
+  numpy,
+  pandas,
+  pathspec,
+  pyproject-metadata,
+  pybind11,
+  pytestCheckHook,
+  pythonOlder,
+  scikit-build-core,
+  scipy,
 }:
 
 buildPythonPackage rec {
@@ -24,7 +22,7 @@ buildPythonPackage rec {
   version = "0.12.4";
   pyproject = true;
 
-  disabled = pythonOlder "3.7";
+  disabled = pythonOlder "3.8";
 
   src = fetchFromGitHub {
     owner = "KaveIO";
@@ -33,58 +31,35 @@ buildPythonPackage rec {
     hash = "sha256-YsH7vVn6gzejunUjUY/RIcvWtaQ/W1gbciJWKi5LDTk=";
   };
 
-  nativeBuildInputs = [
+  build-system = [
     cmake
     ninja
-    scikit-build
-    setuptools
+    pathspec
+    pybind11
+    pyproject-metadata
+    scikit-build-core
   ];
 
-  propagatedBuildInputs = [
+  dependencies = [
     joblib
+    matplotlib
     numpy
-    scipy
     pandas
-    matplotlib
-    numba
-    pybind11
+    scipy
   ];
 
-  nativeCheckInputs = [
-    pytestCheckHook
-    nbconvert
-    jupyter
-    jupyter-client
-  ];
+  nativeCheckInputs = [ pytestCheckHook ];
 
   # Uses setuptools to drive build process
   dontUseCmakeConfigure = true;
 
-  pythonImportsCheck = [
-    "phik"
-  ];
-
-  postInstall = ''
-    rm -r $out/bin
-  '';
+  pythonImportsCheck = [ "phik" ];
 
   preCheck = ''
     # import from $out
     rm -r phik
   '';
 
-  disabledTests = [
-    # TypeError: 'numpy.float64' object cannot be interpreted as an integer
-    # https://github.com/KaveIO/PhiK/issues/73
-    "test_significance_matrix_hybrid"
-    "test_significance_matrix_mc"
-  ];
-
-  disabledTestPaths = [
-    # Don't test integrations
-    "tests/phik_python/integration/"
-  ];
-
   meta = with lib; {
     description = "Phi_K correlation analyzer library";
     longDescription = ''
@@ -33,58 +31,35 @@ buildPythonPackage rec {
 
-  # Uses setuptools to drive build process
+  # Uses scikit-build-core to drive build process
   dontUseCmakeConfigure = true;
 